@@ -3,6 +3,7 @@ import os
 
 class ScoringConfiguration(object):
     """Manages scoring configuration files"""
+
     @staticmethod
     def parse_file(file_name):
         functions = {}
@@ -11,7 +12,7 @@ class ScoringConfiguration(object):
             for line in lines:
                 try:
                     line = line.rstrip(os.linesep)
-                    if not line.startswith('#'):
+                    if not line.startswith("#"):
                         fields = line.split()
                         function_name = fields[0]
                         weight = float(fields[1])
